Later todo

  - [ ] Make config typed

  - [ ] Add checking if git dirty or not pushed
  - [ ] Add some log statistics
  - [ ] Add some firewall statistics
  - [ ] Add updates
  - [ ] Add changelog (linux)
  - [ ] Add news, linux, hackernews?
  - [ ] Add website status check
  - [ ] Add google analytics check
  - [ ] But also constant ingress and event push (tetsuya)
  - [ ] Add something that checks on any request
